@@ -1,9 +1,9 @@
 package Tapper::TAP::Harness;
-# git description: v5.0.0-1-g0c8b930
+# git description: v5.0.1-3-g9821ade
 
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Tapper - Tapper specific TAP handling
-$Tapper::TAP::Harness::VERSION = '5.0.1';
+$Tapper::TAP::Harness::VERSION = '5.0.2';
 use 5.010;
 use strict;
 use warnings;
@@ -70,9 +70,13 @@ our $re_tapper_meta_section   = qr/^#\s*((?:Tapper|Artemis|Test)-Section:)\s*(\S
 our $re_explicit_section_start = qr/^#\s*((?:Tapper|Artemis|Test)-explicit-section-start:)\s*(\S*)/i;
 
 sub _get_prove {
-        my $prove = $^X;
-        $prove =~ s/perl([\d.]*)$/prove$1/;
-        return $prove;
+        my $prove1;
+        my $prove2;
+        ($prove1 = $^X) =~ s/perl([\d.]*)$/prove$1/;
+        ($prove2 = $^X) =~ s/[^\/]*$/prove/;
+        return $prove1 if -e $prove1;
+        return $prove2 if -e $prove2;
+        return; # undef/fail
 }
 
 # report a uniqe section name
@@ -539,9 +543,8 @@ sub generate_html
         my $TAPVERSION = "TAP Version 13";
         my @files = map {
                          if ($_->{section_name} =~ m'(^\.{1,2})|/') {
-                                 $_->{section_name} =~ s/^\./_dot_/g;
-                                 $_->{section_name} =~ s|/|_slash_|g;
-                                 $_->{section_name} = "autogenerated_filename_$_->{section_name}";
+                                 $_->{section_name} =~ s/^\.+$/_dot_/;
+                                 $_->{section_name} =~ s|^/||;
                          }
                          my $fname          = "section/$_->{section_name}";
                          my $rawtap         = $_->{raw};
@@ -555,7 +558,7 @@ sub generate_html
         # Currently a TAP::Formatter::* is only usable via the
         # TAP::Harness which in turn is easiest to use externally on
         # unix shell level
-        my $prove = _get_prove();
+        my $prove = _get_prove() or die "Can not find 'prove', searched near $^X";
 
         my $cmd = qq{cd $temp/section ; $^X $prove -vm --exec 'cat' --formatter=TAP::Formatter::HTML `find -type f | sed -e 's,^\./,,' | sort`};
         my $html = qx( $cmd );
@@ -618,7 +621,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2016 by Advanced Micro Devices, Inc.
 
 This is free software, licensed under:
 
